==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/views/campaign_conditions/new.html.erb_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')

describe "/campaign_conditions/new.html.erb" do
  include CampaignConditionsHelper
  
  before(:each) do
    assigns[:campaign_condition] = stub_model(CampaignCondition,
      :new_record? => true,
      :campaign_id => 1,
      :no => 1,
      :type_cd => "01",
      :operator_cd => "01",
      :value => 'some value',
      :connector_cd => "01",
      :brace_begin_count => 1,
      :brace_end_count => 1
    )
  end

  it "renders new campaign_condition form" do
    render
    
    # response.should have_tag("form[action=?][method=post]", url_for(:controller => 'campaign_conditions', :action => 'create')) do
      # with_tag("input[id=?][type=text]", /CampaignCondition_\d+_campaign_display/)
      # with_tag("input[id=?][type=?][name=?]", /CampaignCondition_\d+_campaign_fk/, /text|hidden/, "campaign_condition[campaign_id]")
    response.should have_tag("div.row") do
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_campaign_id/ , /campaign\[conditions_attributes\]\[\d+\]\[campaign_id\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_no/          , /campaign\[conditions_attributes\]\[\d+\]\[no\]/)
      with_tag("select[id=?][name=?]",                        /campaign_conditions_attributes_\d+_type_cd/     , /campaign\[conditions_attributes\]\[\d+\]\[type_cd\]/)
      with_tag("select[id=?][name=?]",                        /campaign_conditions_attributes_\d+_operator_cd/ , /campaign\[conditions_attributes\]\[\d+\]\[operator_cd\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_value/       , /campaign\[conditions_attributes\]\[\d+\]\[value\]/)
      with_tag("select[id=?][name=?]",                        /campaign_conditions_attributes_\d+_connector_cd/, /campaign\[conditions_attributes\]\[\d+\]\[connector_cd\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_brace_begin_count/, /campaign\[conditions_attributes\]\[\d+\]\[brace_begin_count\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_brace_end_count/  , /campaign\[conditions_attributes\]\[\d+\]\[brace_end_count\]/)
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/views/campaign_conditions/new.html.erb_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')

describe "/campaign_conditions/new.html.erb" do
  include CampaignConditionsHelper
  
  before(:each) do
    assigns[:campaign_condition] = stub_model(CampaignCondition,
      :new_record? => true,
      :campaign_id => 1,
      :no => 1,
      :type_cd => "01",
      :operator_cd => "01",
      :value => 'some value'
    )
  end

  it "renders new campaign_condition form" do
    pending
    render
    
    # response.should have_tag("form[action=?][method=post]", url_for(:controller => 'campaign_conditions', :action => 'create')) do
      # with_tag("input[id=?][type=text]", /CampaignCondition_\d+_campaign_display/)
      # with_tag("input[id=?][type=?][name=?]", /CampaignCondition_\d+_campaign_fk/, /text|hidden/, "campaign_condition[campaign_id]")
    response.should have_tag("div.row") do
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_campaign_id/ , /campaign\[conditions_attributes\]\[\d+\]\[campaign_id\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_no/          , /campaign\[conditions_attributes\]\[\d+\]\[no\]/)
      with_tag("select[id=?][name=?]",                        /campaign_conditions_attributes_\d+_type_cd/     , /campaign\[conditions_attributes\]\[\d+\]\[type_cd\]/)
      with_tag("select[id=?][name=?]",                        /campaign_conditions_attributes_\d+_operator_cd/ , /campaign\[conditions_attributes\]\[\d+\]\[operator_cd\]/)
      with_tag("input[type=?][id=?][name=?]", /text|hidden/i, /campaign_conditions_attributes_\d+_value/       , /campaign\[conditions_attributes\]\[\d+\]\[value\]/)
    end
  end
end
